summaryrefslogtreecommitdiff
path: root/mm/src/code
diff options
context:
space:
mode:
authorEblo <7004497+Eblo@users.noreply.github.com>2025-10-30 20:26:35 -0400
committerGitHub <noreply@github.com>2025-10-30 20:26:35 -0400
commit8c9e6dca046941bebcb5d68170c686388e2596dd (patch)
tree3bc7a36ca82c3c80f3c706b0275003f675a595e1 /mm/src/code
parent04cf7fbf0200db67946a430f6a5ef10289cb965d (diff)
Convert to ObjectExtension (#1299)
* Replace ActorExtension with ObjectExtension * We only need cassert here, not all of LUS * Expose ObjectExtension_Free to C++ * Remove unneeded vector include
Diffstat (limited to 'mm/src/code')
-rw-r--r--mm/src/code/z_actor.c15
1 files changed, 7 insertions, 8 deletions
diff --git a/mm/src/code/z_actor.c b/mm/src/code/z_actor.c
index dc7742660..00c473524 100644
--- a/mm/src/code/z_actor.c
+++ b/mm/src/code/z_actor.c
@@ -28,8 +28,8 @@
#include "2s2h/GameInteractor/GameInteractor.h"
#include "2s2h/BenPort.h"
#include "2s2h/ShipUtils.h"
-#include "2s2h/ActorExtension/ActorExtension.h"
-#include "2s2h/ActorExtension/ActorListIndex.h"
+#include "2s2h/ObjectExtension/ObjectExtension.h"
+#include "2s2h/ObjectExtension/ActorListIndex.h"
#include <libultraship/bridge/consolevariablebridge.h>
// bss
@@ -2661,7 +2661,7 @@ void Actor_SpawnSetupActors(PlayState* play, ActorContext* actorCtx) {
shiftedHalfDaysBit = (actorCtx->halfDaysBit << 1) & (HALFDAYBIT_ALL & ~HALFDAYBIT_DAY0_NIGHT);
for (i = 0; i < play->numSetupActors; i++) {
// 2S2H [ActorExtension] store the actor's index to be used for identification
currentActorListIndex = i;
actorEntryHalfDayBit = ((actorEntry->rot.x & 7) << 7) | (actorEntry->rot.z & 0x7F);
@@ -2676,7 +2676,7 @@ void Actor_SpawnSetupActors(PlayState* play, ActorContext* actorCtx) {
}
actorEntry++;
}
// 2S2H [ActorExtension] Reset the currentActorListIndex
currentActorListIndex = -1;
// Prevents re-spawning the setup actors
@@ -3754,8 +3754,7 @@ Actor* Actor_SpawnAsChildAndCutscene(ActorContext* actorCtx, PlayState* play, s1
return NULL;
}
- // #region 2S2H [ActorExtension]
- ActorExtension_Alloc(actor, profile->id);
+ // #region 2S2H [ObjectExtension]
SetActorListIndex(actor, currentActorListIndex);
currentActorListIndex = -1;
// #endregion
@@ -3920,8 +3919,8 @@ Actor* Actor_Delete(ActorContext* actorCtx, Actor* actor, PlayState* play) {
newHead = Actor_RemoveFromCategory(play, actorCtx, actor);
- // #region 2S2H [ActorExtension]
- ActorExtension_Free(actor);
+ // #region 2S2H [ObjectExtension]
+ ObjectExtension_Free(actor);
// #endregion
ZeldaArena_Free(actor);
@@ -2661,7 +2661,7 @@ void Actor_SpawnSetupActors(PlayState* play, ActorContext* actorCtx) {
shiftedHalfDaysBit = (actorCtx->halfDaysBit << 1) & (HALFDAYBIT_ALL & ~HALFDAYBIT_DAY0_NIGHT);
for (i = 0; i < play->numSetupActors; i++) {
- // 2S2H [ActorExtension] store the actor's index to be used for identification
+ // 2S2H [ObjectExtension] store the actor's index to be used for identification
currentActorListIndex = i;
actorEntryHalfDayBit = ((actorEntry->rot.x & 7) << 7) | (actorEntry->rot.z & 0x7F);
@@ -2676,7 +2676,7 @@ void Actor_SpawnSetupActors(PlayState* play, ActorContext* actorCtx) {
actorEntry++;
}
- // 2S2H [ActorExtension] Reset the currentActorListIndex
+ // 2S2H [ObjectExtension] Reset the currentActorListIndex
currentActorListIndex = -1;
// Prevents re-spawning the setup actors